pub struct KeysManagerClient { /* private fields */ }Implementations
Sourceimpl KeysManagerClient
impl KeysManagerClient
Sourcepub fn new(
transport: Arc<dyn Transport>,
network: String,
key_derivation_style: Option<KeyDerivationStyle>,
dev_allowlist: Option<Array<WireString>>,
receive_auth_key: ReceiveAuthKey,
) -> Self
pub fn new( transport: Arc<dyn Transport>, network: String, key_derivation_style: Option<KeyDerivationStyle>, dev_allowlist: Option<Array<WireString>>, receive_auth_key: ReceiveAuthKey, ) -> Self
Create a new VLS client with the given transport.
receive_auth_key is the LDK 0.2 blinded-path MAC key. Its only
requirement is to be consistent across invocations, so the caller is
responsible for generating it (e.g. on first run) and persisting it
in its own state — see NodeSigner::get_receive_auth_key in LDK.
The signer does not provide it, since any caller with persistence
can.
peer_storage_key and the inbound-payment ExpandedKey seed are in
contrast obtained from the signer’s HsmdInit2Reply: LDK requires them
to be stable across restarts (state-loss recovery, and receivable
invoices respectively) and the signer is the only place that holds the
seed they derive from.
pub fn call<T: SerBolt, R: DeBolt>(&self, message: T) -> Result<R, Error>
pub fn sign_onchain_tx( &self, tx: &Transaction, descriptors: &[&SpendableOutputDescriptor], ) -> Vec<Vec<Vec<u8>>>